@@ -13,7 +13,7 @@ require QWidget;
 @ISA = qw(Exporter DynaLoader QWidget);
 @EXPORT = qw(%Frame);
 
-$VERSION = '0.03';
+$VERSION = '1.00';
 bootstrap QFrame $VERSION;
 
 1;
@@ -35,6 +35,9 @@ Requires QRect.
 
 new,
 contentsRect,
+drawContents,
+drawFrame,
+frameChanged,
 frameRect,
 frameShadow,
 frameShape,
@@ -43,10 +46,22 @@ frameWidth,
 lineShapesOk,
 lineWidth,
 midLineWidth,
+setFrameRect,
 setFrameStyle,
 setLineWidth,
 setMidLineWidth
 
+=head2 Overridable functions
+
+drawContents,
+drawFrame,
+frameChanged
+
+=head2 Overridden functions
+
+paintEvent,
+resizeEvent
+
 =head1 DESCRIPTION
 
 As direct an interface as humanly possible.
@@ -54,7 +69,8 @@ As direct an interface as humanly possible.
 =head1 EXPORTED
 
 Exports C<%Frame> into the user's namespace. It contains all the constants
-accessed through QFrame:: in C++
+accessed through QFrame:: in C++. QFrame::NoFrame has been changed to
+$Frame{None}.
 
 =head1 SEE ALSO
 
