@@ -12,7 +12,7 @@ require QColor;
 @ISA = qw(Exporter DynaLoader Qt::Base);
 @EXPORT = qw(%Pen);
 
-$VERSION = '0.03';
+$VERSION = '1.00';
 bootstrap QPen $VERSION;
 
 1;
@@ -45,7 +45,10 @@ Except for the operators, this class is fully implemented.
 =head1 EXPORTED
 
 The C<%Pen> hash is exported into the user's namespace, and contains
-all of the elements from the PenStyle enum defined in F<qpen.h>.
+all of the elements from the PenStyle enum defined in F<qpen.h>. The
+C<NoPen> constant has been changed to C<$Pen{None}> and all the other
+constants have had their appended Line's removed; thereby making 
+C<SolidLine> become C<$Pen{Solid}>, and so on.
 
 =head1 SEE ALSO
 
